@@ -2,10 +2,11 @@
 #define _IG_WIN32_H
 
 #if PHP_WIN32
-# include "win32/php_stdint.h"
 # if defined(_MSC_VER) && _MSC_VER >= 1800
 #  include <stdbool.h>
+#  include <stdint.h>
 # else
+#  include "win32/php_stdint.h"
 #  ifndef inline
 #  define inline __inline
 #  endif
@@ -24,6 +25,9 @@ typedef bool _Bool;
 #  define true 1
 #  define __bool_true_false_are_defined 1
 # endif /* __MSC_VER */
+# ifdef _DEBUG
+#  include <crtdbg.h>
+# endif
 #endif /* PHP_WIN32 */
 
 #endif  /* _IG_WIN32_H */
